Add executable names (fix #6)
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 4aa036b..6120ba2 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,5 +1,8 @@
 # Changelog
 
+## 0.0.3
+- Added executable names
+
 ## 0.0.2
 - Add support for ConstantInfo
 
diff --git a/README.md b/README.md
index 5ba0d38..37a4151 100644
--- a/README.md
+++ b/README.md
@@ -89,8 +89,9 @@
 
 Run this tool as follows:
 ```bash
-pub global activate dart2js_info # only needed once
-pub global run dart2js_info:code_deps out.js.info.json some_path main foo
+# activate is only needed once to install the dart2js_info* executables
+pub global activate dart2js_info
+dart2js_info_code_deps out.js.info.json some_path main foo
 ```
 
 The arguments to the query are regular expressions that can be used to
@@ -112,7 +113,7 @@
 
 ```bash
 pub global activate dart2js_info # only needed once
-pub global run dart2js_info:library_size_split out.js.info.json
+dart2js_info_library_size_split out.js.info.json
 ```
 
 
@@ -120,7 +121,7 @@
 specify what regular expressions to use by providing a `grouping.yaml` file:
 
 ```bash
-pub global run dart2js_info:library_size_split out.js.info.json grouping.yaml
+dart2js_info_library_size_split out.js.info.json grouping.yaml
 ```
 
 The format of the `grouping.yaml` file is as follows:
@@ -194,7 +195,7 @@
 When you run:
 ```bash
 pub global activate dart2js_info # only needed once
-pub global run dart2js_info:function_size_analysis out.js.info.json
+dart2js_info_function_size_analysis out.js.info.json
 ```
 
 the tool produces a table output with lots of entries. Here is an example entry
@@ -236,7 +237,7 @@
   * Launch the coverage server tool to serve up the JS code of your app:
 
 ```bash
-pub global run dart2js_info:coverage_log_server main.dart.js
+dart2js_info_coverage_log_server main.dart.js
 ```
 
   * (optional) If you have a complex application setup, you may need to serve an
@@ -253,7 +254,7 @@
     converage json files:
 
 ```bash
-pub global run dart2js_info:live_code_size_analysis main.dart.info.json main.dart.coverage.json
+dart2js_info_live_code_size_analysis main.dart.info.json main.dart.coverage.json
 ```
 
 ## Code location, features and bugs
diff --git a/pubspec.yaml b/pubspec.yaml
index 70f7184..9dac77f 100644
--- a/pubspec.yaml
+++ b/pubspec.yaml
@@ -1,5 +1,5 @@
 name: dart2js_info
-version: 0.0.2
+version: 0.0.3
 description: >
   Libraries and tools to process data produced when running dart2js with
   --dump-info.
@@ -17,3 +17,10 @@
 
 dev_dependencies:
   test: ^0.12.3+4
+executables:
+  dart2js_info_code_deps:               code_deps
+  dart2js_info_coverage_log_server:     coverage_log_server
+  dart2js_info_debug_info:              debug_info
+  dart2js_info_function_size_analysis:  function_size_analysis
+  dart2js_info_library_size_split:      library_size_split
+  dart2js_info_live_code_size_analysis: live_code_size_analysis
diff --git a/bin/code_deps.dart b/bin/code_deps.dart
index a8e8902..0ad189b 100644
--- a/bin/code_deps.dart
+++ b/bin/code_deps.dart
@@ -9,7 +9,7 @@
 /// You can run this tool as follows:
 /// ```bash
 /// pub global activate dart2js_info
 /// pub global run dart2js_info:code_deps out.js.info.json some_path main foo
 /// ```
 ///
 /// The arguments to the query are regular expressions that can be used to
@@ -35,8 +35,7 @@
 
 main(args) {
   if (args.length < 2) {
-    print('usage: pub global run dart2js_info:code_deps '
-        'path-to.info.json <query>');
+    print('usage: dart2js_info_code_deps path-to.info.json <query>');
     print('   where <query> can be:');
     print('     - some_path <element-regexp-1> <element-regexp-2>');
     // TODO(sigmund): add other queries, such as 'all_paths'.
@@ -9,7 +9,7 @@
 /// ```bash
 /// pub global activate dart2js_info
-/// pub global run dart2js_info:code_deps out.js.info.json some_path main foo
+/// dart2js_info_code_deps out.js.info.json some_path main foo
 /// ```
 ///